/*********************************************************************/
/*                                                                   */
/*  AINUEXIT.H :  User Exit Declarations                             */
/*                                                                   */
/*  This file contains function and structure declarations for       */
/*  the AIN user exits.                                              */
/*                                                                   */
/*                                                                   */
/* COPYRIGHT: 20G0732 (C) COPYRIGHT IBM CORPORATION 1987, 1992       */
/*            LICENSED MATERIAL - PROPERTY OF IBM                    */
/*            SEE COPYRIGHT INSTRUCTIONS G120-2083                   */
/*                                                                   */
/* NOTE: This program sample is provided on an as-is basis.          */
/*       The licensee of the PSF/2 product is free to copy, revise,  */
/*       modify, and make derivative works of this program sample    */
/*       as they see fit.                                            */
/*                                                                   */
/*                                                                   */
/* STATUS = RELEASE 1  LEVEL 0                                       */
/*                                                                   */
/*                                                                   */
/* NOTES:   All strings are NULL (0x00) terminated.                  */
/*                                                                   */
/*                                                                   */
/* CHANGE ACTIVITY:                                                  */
/*                                                                   */
/* PROBNO  REL   DATE/AUTHOR DESCRIPTION                        FICHE*/
/* ------- ----- ----------- -----------                        -----*/
/*                                                                   */
/*                                                                   */
/*********************************************************************/

#if !defined(_SIZE_T_DEFINED)
typedef unsigned int size_t;
#define _SIZE_T_DEFINED
#endif

/*********************************************************************/
/* User exit signature - Do not change this next line                */
/*********************************************************************/
char pascal AIN49F4804;

/*********************************************************************/
/* CHARACTER STRING CONSTANTS                                        */
/*********************************************************************/
#define NOT_AVAILABLE   "Not Available"
#define SYSTEM          "System"
#define LOCAL           "Local"

/*********************************************************************/
/* JOB COMPLETION CODES                                              */
/*********************************************************************/
#define JOBC_OK 0                       /* good completion           */
#define JOBC_NONFATAL -1                /* non-fatal error           */
#define JOBC_FATALERROR -5              /* fatal user exit error     */
#define JOBC_TERMJOB -8                 /* terminate current job     */
#define JOBC_ABEND -12                  /* ABEND AIN                 */

/*********************************************************************/
/* MISCELLANEOUS DEFINES                                             */
/*********************************************************************/
#define DATATYPE_AFPDS 0                /* AFPDS data stream         */
#define DATATYPE_ASCII 1                /* ASCII data stream         */

/*********************************************************************/
/* EXITDATA FIELD SIZES.  These are the maximum string lengths and   */
/* do not include the trailing 0x00 byte.                            */
/*********************************************************************/
#define USERID_SIZE 8                   /* size of UserID            */
#define NODEID_SIZE 8                   /* size of NodeID            */
#define JOBNAME_SIZE 255                /* size of JobName           */
#define PRINTERNAME_SIZE 8              /* size of PrinterName       */
#define DATE_SIZE 8                     /* size of Date              */
#define TIME_SIZE 8                     /* size of Time              */
#define DISTRIBUTION_SIZE 8             /* size of Distribution      */
#define EXT_USERID_SIZE 10              /* size of UserID            */
#define EXT_NODEID_SIZE 10              /* size of NodeID            */

/*********************************************************************/
/* HEADER AND TRAILER EXITDATA STRUCTURES                            */
/*********************************************************************/
#define HEADER_EXITDATA struct header_exitdata
#define TRAILER_EXITDATA HEADER_EXITDATA
HEADER_EXITDATA
{
  char         UserID[USERID_SIZE + 1];
  char         NodeID[NODEID_SIZE + 1];
  char         JobName[JOBNAME_SIZE + 1];
  unsigned int SpoolID;
  char         PrinterName[PRINTERNAME_SIZE + 1];
  char         reserved1;
  HAB          hab;
  char         Date[DATE_SIZE + 1];
  char         Time[TIME_SIZE + 1];
  char         FileDate[DATE_SIZE + 1];
  char         FileTime[TIME_SIZE + 1];
  char         Distribution[DISTRIBUTION_SIZE + 1];
  char         reserved2;
  void far     *PagePointer;
  size_t       PageSize;
  int          PageType;
  int          JobCompletion;
  char         ExtendedUserID[EXT_USERID_SIZE + 1];
  char         ExtendedNodeID[EXT_NODEID_SIZE + 1];
};

/*********************************************************************/
/* SEPARATOR EXITDATA STRUCTURE                                      */
/*********************************************************************/
#define SEPARATOR_EXITDATA struct separator_exitdata
SEPARATOR_EXITDATA
{
  char         UserID[USERID_SIZE + 1];
  char         NodeID[NODEID_SIZE + 1];
  char         JobName[JOBNAME_SIZE + 1];
  unsigned int SpoolID;
  char         PrinterName[PRINTERNAME_SIZE + 1];
  char         reserved1;
  HAB          hab;
  char         Date[DATE_SIZE + 1];
  char         Time[TIME_SIZE + 1];
  char         FileDate[DATE_SIZE + 1];
  char         FileTime[TIME_SIZE + 1];
  char         Distribution[DISTRIBUTION_SIZE + 1];
  char         reserved2;
  unsigned int Copy;
  void far     *PagePointer;
  size_t       PageSize;
  int          PageType;
  int          JobCompletion;
  char         ExtendedUserID[EXT_USERID_SIZE + 1];
  char         ExtendedNodeID[EXT_NODEID_SIZE + 1];
};

/*********************************************************************/
/* ACCOUNTING AND AUDIT EXITDATA STRUCTURES                          */
/*********************************************************************/
#define ACCOUNTING_EXITDATA struct accounting_exitdata
#define AUDIT_EXITDATA ACCOUNTING_EXITDATA
ACCOUNTING_EXITDATA
{
  char          UserID[USERID_SIZE + 1];
  char          NodeID[NODEID_SIZE + 1];
  char          JobName[JOBNAME_SIZE + 1];
  unsigned int  SpoolID;
  char          PrinterName[PRINTERNAME_SIZE + 1];
  char          reserved1;
  HAB           hab;
  unsigned long PagesPrinted;
  unsigned long BinOneSheets;
  unsigned long BinTwoSheets;
  unsigned long FontsUsed;
  unsigned long OverlaysUsed;
  unsigned long HardSegmentsUsed;
  char          StartDate[DATE_SIZE + 1];
  char          StartTime[TIME_SIZE + 1];
  char          EndDate[DATE_SIZE + 1];
  char          EndTime[TIME_SIZE + 1];
  char          FileDate[DATE_SIZE + 1];
  char          FileTime[TIME_SIZE + 1];
  void far      *PagePointer;
  size_t        PageSize;
  int           PageType;
  int           JobCompletion;
  char         ExtendedUserID[EXT_USERID_SIZE + 1];
  char         ExtendedNodeID[EXT_NODEID_SIZE + 1];
};

/*********************************************************************/
/* INPUT DATA STREAM EXITDATA STRUCTURE                              */
/*********************************************************************/
#define INDATA_EXITDATA struct indata_exitdata
INDATA_EXITDATA
{
  char          UserID[USERID_SIZE + 1];
  char          NodeID[NODEID_SIZE + 1];
  char          JobName[JOBNAME_SIZE + 1];
  unsigned int  SpoolID;
  char          PrinterName[PRINTERNAME_SIZE + 1];
  char          reserved1;
  HAB           hab;
  unsigned int  Copy;
  size_t        DataSize;
  void far      *DataPointer;
  int           DataType;
  int           JobCompletion;
  char         ExtendedUserID[EXT_USERID_SIZE + 1];
  char         ExtendedNodeID[EXT_NODEID_SIZE + 1];
};

/*********************************************************************/
/* OUTPUT DATA STREAM EXITDATA STRUCTURE                             */
/*********************************************************************/
#define OUTDATA_EXITDATA struct outdata_exitdata
OUTDATA_EXITDATA
{
  char          UserID[USERID_SIZE + 1];
  char          NodeID[NODEID_SIZE + 1];
  char          JobName[JOBNAME_SIZE + 1];
  unsigned int  SpoolID;
  char          PrinterName[PRINTERNAME_SIZE + 1];
  char          reserved1;
  HAB           hab;
  unsigned int  Copy;
  size_t        DataSize;
  void far      *DataPointer;
  int           JobCompletion;
  char         ExtendedUserID[EXT_USERID_SIZE + 1];
  char         ExtendedNodeID[EXT_NODEID_SIZE + 1];
};

/*********************************************************************/
/* FUNCTION DECLARATIONS                                             */
/*********************************************************************/
void far pascal HEADER(HEADER_EXITDATA far *exitdata);
void far pascal TRAILER(TRAILER_EXITDATA far *exitdata);
void far pascal SEPARATOR(SEPARATOR_EXITDATA far *exitdata);
void far pascal ACCOUNTING(ACCOUNTING_EXITDATA far *exitdata);
void far pascal AUDIT(AUDIT_EXITDATA far *exitdata);
void far pascal INDATA(INDATA_EXITDATA far *exitdata);
void far pascal OUTDATA(OUTDATA_EXITDATA far *exitdata);
