#define  INCL_WIN
#include <os2.h>
#include <memory.h>
#include <string.h>
#include <stdio.h>

#include "ainuexit.h"

/*********************************************************************/
/*                                                                   */
/* MODULE NAME: AINUXACC.C                                           */
/*                                                                   */
/*                                                                   */
/* SYNOPSIS:  PSF/2 default Accounting Exit                          */
/*                                                                   */
/*                                                                   */
/* DESCRIPTION:  This module contains the ACCOUNTING function, which */
/*               is he default Accounting Exit.                      */
/*                                                                   */
/*                                                                   */
/* COPYRIGHT: 20G0732 (C) COPYRIGHT IBM CORPORATION 1987, 1992       */
/*            LICENSED MATERIAL - PROPERTY OF IBM                    */
/*            SEE COPYRIGHT INSTRUCTIONS G120-2083                   */
/*                                                                   */
/* NOTE: This program sample is provided on an as-is basis.          */
/*       The licensee of the PSF/2 product is free to copy, revise,  */
/*       modify, and make derivative works of this program sample    */
/*       as they see fit.                                            */
/*                                                                   */
/* STATUS = RELEASE 1  LEVEL 0                                       */
/*                                                                   */
/*                                                                   */
/* EXTERNAL STATIC VARIABLES: None                                   */
/*                                                                   */
/*                                                                   */
/* NOTES:                                                            */
/*                                                                   */
/*                                                                   */
/* CHANGE ACTIVITY:                                                  */
/*                                                                   */
/* PROBNO  REL   DATE/AUTHOR DESCRIPTION                        FICHE*/
/* ------- ----- ----------- -----------                        -----*/
/*                                                                   */
/*                                                                   */
/*********************************************************************/

/*********************************************************************/
/*                                                                   */
/* FUNCTION NAME:  ACCOUNTING                                        */
/*                                                                   */
/* SYNOPSIS:  Accounting user exit                                   */
/*                                                                   */
/* DESCRIPTION:  This function is the Accounting user exit.  It      */
/*               generates ASCII data showing the input parameters.  */
/*                                                                   */
/* INPUT:                                                            */
/*    NAME: exitdata                                                 */
/*    TYPE: ACCOUNTING_EXITDATA                                      */
/*    DESC: User exit input and output structure                     */
/*                                                                   */
/* OUTPUT:                                                           */
/*                                                                   */
/*    TYPE: size_t                                                   */
/*    DESC: VARIABLE POINTED TO BY:  exitdata->PageSize              */
/*          Size of the valid page data in the page buffer.          */
/*                                                                   */
/*    TYPE: int                                                      */
/*    DESC: VARIABLE POINTED TO BY:  exitdata->PageType              */
/*          This is always set to DATATYPE_ASCII.                    */
/*                                                                   */
/*    TYPE: int                                                      */
/*    DESC: VARIABLE POINTED TO BY:  exitdata->JobCompletion         */
/*          This is always set to 0 (Successful).                    */
/*                                                                   */
/* RETURNS: void                                                     */
/*                                                                   */
/* INTERNAL STATIC VARIABLES:  None                                  */
/*                                                                   */
/* NOTES:                                                            */
/*                                                                   */
/*********************************************************************/

void far pascal ACCOUNTING(ACCOUNTING_EXITDATA far *exitdata)
{

  /*******************************************************************/
  /* Create ASCII data representing the input parameters.            */
  /*******************************************************************/
  sprintf( exitdata->PagePointer,
             "UserID=%s\r\n"
             "NodeID=%s\r\n"
             "JobName=%s\r\n"
             "SpoolID=%u\r\n"
             "PrinterName=%s\r\n"
             "PagesPrinted=%lu\r\n"
             "BinOneSheets=%lu\r\n"
             "BinTwoSheets=%lu\r\n"
             "FontsUsed=%lu\r\n"
             "OverlaysUsed=%lu\r\n"
             "HardSegmentsUsed=%lu\r\n"
             "StartDate=%s\r\n"
             "StartTime=%s\r\n"
             "EndDate=%s\r\n"
             "EndTime=%s\r\n"
             "FileDate=%s\r\n"
             "FileTime=%s\r\n\0",
              exitdata->UserID,
              exitdata->NodeID,
              exitdata->JobName,
              exitdata->SpoolID,
              exitdata->PrinterName,
              exitdata->PagesPrinted,
              exitdata->BinOneSheets,
              exitdata->BinTwoSheets,
              exitdata->FontsUsed,
              exitdata->OverlaysUsed,
              exitdata->HardSegmentsUsed,
              exitdata->StartDate,
              exitdata->StartTime,
              exitdata->EndDate,
              exitdata->EndTime,
              exitdata->FileDate,
              exitdata->FileTime );

  /*******************************************************************/
  /* Set length of ASCII data.                                       */
  /*******************************************************************/
  exitdata->PageSize = strlen( exitdata->PagePointer );

  /*******************************************************************/
  /* Indicate that the data is ASCII.                                */
  /*******************************************************************/
  exitdata->PageType = DATATYPE_ASCII;

  /*******************************************************************/
  /* Return with a successful JobCompletion                          */
  /*******************************************************************/
  return;

}
