/****************************************************************/
/* NETWARE.CMD takes a file from NOVELL with a PostScript header*/
/* page on it, and does the following:                          */
/*   - Removes the Postscript header page from the file         */
/*   - Takes data from the Postscript header page, and uses it  */
/*     in an APRINT command to allow PSF/2 to create an         */
/*     appropriate header page.                                 */
/*                                                              */
/* To set it up you must do the following:                      */
/*   - Place this CMD file in the \PSF2\SAMPLES\ directory      */
/*     on the PSF/2 machine.                                    */
/*   - Create an intermediate queue invoking this command file. */
/*     See the HELP section below for command format and more   */
/*     details.  For information on how to create an            */
/*     intermediate queue with XFMFLTR, see the PSF/2 WHAT'S    */
/*     NEW online document in the PSF/2 folder.                 */
/*   - Set up NETWARE to use PSERVER and to add a Postscript    */
/*     header page to the file.  The file can be of any type,   */
/*     and does not need to be Postscript, only the header page */
/*     needs to be Postscript.                                  */
/*   - Make sure NETWARE is sending the document to the         */
/*     new intermediate queue.                                  */
/*                                                              */
/* Things to be careful of:                                     */
/*   - Make sure you have AT LEAST 3 times the size of your     */
/*     largest job available as disk space for the OS/2 Spool   */
/*     subdirectory.  If you don't, you run the risk of         */
/*     overflowing the disk space and having other problems.    */
/*                                                              */
/* The parameters are:                                          */
/*   - Input file name                                          */
/*   - Output file name                                         */
/*   - Output queue name (for APRINT command to use)            */
/*                                                              */
/* This command is meant to be used as part of the Transform    */
/* Exit being invoked by XFMFLTR or GENERIC Transform Exits.    */
/****************************************************************/

/* Save local environment to make sure no changes are made. */
x = setlocal()

/* Don't echo commands */
echo = '@'

/* Read in the parameters from the command line */
ARG commandline

/* Check command line parameters */
if WORDS(commandline) <> 0 then do
  if WORDS(commandline) = 3 then do
    inputdat = WORD(commandline, 1)
    outputdat = WORD(commandline, 2)
    queuename = WORD(commandline, 3)
  end
  else do
    CALL HELP;
  end
end
else do
  CALL HELP;
end

/* Write out parameters to temp file if needed */
/*
tempfile = 'c:\netware.txt'
tempout = 'inputdat = 'inputdat
retcode = LINEOUT(tempfile, tempout);
tempout = 'outputdat = 'outputdat
retcode = LINEOUT(tempfile, tempout);
tempout = 'queuename = 'queuename
retcode = LINEOUT(tempfile, tempout);
*/

/* Make sure output file does not already exist */
if FILESTATE(outputdat)<>0 then do
  echo'erase 'outputdat
end;

/* Initialize variables */
state = HEADER
substate = NONE
curnum = 0
paren = 0
tempc = ''
inputlen = 1800
jobname = ''
jobowner = ''

/* Loop until file is completed */
do while CHARS(inputdat) > 0
  lineloc = 1
  charsleft = CHARS(inputdat)

  CALL READNEXT;

  if charsleft >= inputlen then do
    linelen = inputlen
  end
  else do
    linelen = charsleft
  end

  /* If Processing header page appended by NOVELL */
  if (state = HEADER) then do
    do while ((linelen - lineloc + 1 > 0) & (state = HEADER))
      tempcm1 = tempc
      temp = SUBSTR(curline, lineloc, 1)
      lineloc = lineloc + 1

      tempc = C2X(temp)

      if (tempc = '29') then do
        if (paren = 1) then do
          substate = NONE
        end
        if (paren = 3) then do
          substate = NONE
        end
        paren = paren + 1
      end

      if (substate = JNAME) then do
        jobname = jobname || temp
      end

      if (substate = JOWN) then do
        jobowner = jobowner || temp
      end

      if (tempc = '28') then do
        if (paren = 0) then do
          substate = JNAME
        end
        if (paren = 2) then do
          substate = JOWN
        end
        paren = paren + 1
      end

      if ((tempc = '0A') & (tempcm1 = '0A')) then do
        state = BODY
        curlinet = SUBSTR(curline, lineloc, linelen - lineloc + 1)
        curline = curlinet
        inputlen = 4096
      end
    end
  end

  /* If processing data after header page */
  if (state = BODY) then do
    retcode = CHAROUT(outputdat, curline)
  end
end

/* Close output file */
retcode = LINEOUT(outputdat)

/* Additional processing with 'jobname' and 'jobowner', need to    */
/* remove invalid characters and append jobowner to jobname        */
/* Invalid characters are anything but characters, letters, and    */
/* numbers.  The invalids will have underscores put in their place.*/
i = 1
jobname2 = ''
do while(i <= LENGTH(jobname))
  jobchar = SUBSTR(jobname, i, 1)
  if (POS(jobchar, 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_.') = 0) then do
    jobname2 = jobname2 || '_'
  end
  else do
    jobname2 = jobname2 || jobchar
  end  /* Do */
  i = i + 1
end /* do */

i = 1
jobowner2 = ''
do while((i <= LENGTH(jobowner)) & (i <= 8))
  jobchar = SUBSTR(jobowner, i, 1)
  if (POS(jobchar, 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_') = 0) then do
    jobowner2 = jobowner2 || '_'
  end
  else do
    jobowner2 = jobowner2 || jobchar
  end  /* Do */
  i = i + 1
end /* do */

/* Append jobowner to jobname */
jobname2 = jobname2 || '_' || jobowner2

/* Transfer output file to PSF/2 queue with information for header */
'APRINT 'outputdat' JOBN='jobname2' JOBO='jobowner2' D='queuename

x = endlocal()
CALL QUIT;

READNEXT:;
  curline = ''
  curline = CHARIN(inputdat,, inputlen)
  curnum = curnum + inputlen
RETURN;

HELP:;
  say '**************************************************************';
  say '* This command can be used to remove Postscript headers from *';
  say '* a Novell Netware file.  The data in the Postscript header  *';
  say '* will be extracted by this CMD file (invoked via the XFMFLTR*';
  say '* transform) then passed to the PSF/2 queue via an APRINT    *';
  say '* command.  This command is intended for use with the PSF/2  *';
  say '* Transform Exit layer via the XFMFLTR.DLL or the GENERIC.DLL*';
  say '*                                                            *';
  say '* This command requires three parameters when invoking it    *';
  say '* through the XFMFLTR screen:                                *';
  say '*                                                            *';
  say '* The format is:                                             *';
  say '*   NETWARE <input source> <output source> <queue name>      *';
  say '*                                                            *';
  say '* where:                                                     *';
  say '*   <input source> is the fully qualified name of a file     *';
  say '*     with the data from Netware in it. %i is usually used.  *';
  say '*   <output source> is the fully qualified name of a file    *';
  say '*     where the data is to be placed.  %o is usually used.   *';
  say '*   <queue name> is the name of the PSF/2 queue for the      *';
  say '*     APRINT command DEST parameter.                         *';
  say '*                                                            *';
  say '* Example line to put in XFMFLTR or GENERIC transform:       *';
  say '*   c:\psf2\samples\netware.cmd %i %o PSF4019Q               *';
  say '*   MAKE SURE THE 'TERMINAL TRANSFORM' box is checked!!!     *';
  say '*                                                            *';
  say '**************************************************************';
  x = endlocal()
  CALL QUIT;
RETURN;

FILESTATE:; parse arg fid;
  /* This module tries to locate file. Returns >0 if file found   */
  rc=LENGTH(STREAM(fid,'C','QUERY EXISTS'));
RETURN(rc);

QUIT:;
EXIT;
